function [rbw,t,gain] = specan_parameters(obj,rbw,t,gain)
%SPECAN_PARAMETERS Parameter der Spektralanalysatormessung einstellen
%   Kommunikation erfolgt mit SCPI-Befehlen
%   input arguments
%       obj             Instrument Object
%       rbw             Auflsenbandbreite (3dB-Bandbreite des Gau-Filters),
%                       0 bedeutet Minimalwert
%       t               Mittelungsdauer, 0 bedeutet Minimalwert
%       gain            linearer Gewinn der Signalaufbereitung,
%                       realisiert durch Vorverstrker und Dmpfungsglied
%   output arguments
%       rbw             tatschliche Auflsebandbreite
%       t               tatschliche Mittelungsdauer
%       gain            tatschlicher linearer Gewinn der Signalaufbereitung
%
%   Instrument Control Toolbox 
%       S. 1-23 bis 1-24
%
%   SCPI-Befehle 
%       *RST
%       INSTrument[:SELect] <Application>
%       INITiate<1|2>:CONTinuous ON | OFF
%       [SENSe<1|2>:]FREQuency:SPAN 0 .. fmax
%       [SENSe<1|2>:]BANDwidth|BWIDth[:RESolution] 10 Hz...50 MHz
%       [SENSe<1|2>:]SWEep:TIME 1s... 16000s
%       [SENSe<1|2>:]DETector<1..3>[:FUNCtion] APEak | NEGative | POSitive | SAMPle | RMS | AVERage | QPEak
%       INPut<1|2>:GAIN:STATe ON | OFF
%       INPut<1|2>:ATTenuation 0...75dB
%       DISPlay[:WINDow<1|2>]:TRACe<1...3>:Y[:SCALe]:RLEVel
%
%   05.09.2019          T. Weber    
%   13.12.2020          Untersttzung fr FPC1500 und FPL1003 hinzugefgt

switch obj.Name
    case 'none'
        
    case 'zvl'
        % Preset
        fprintf(obj,'*RST');
        
        % Spektralanalysator aktivieren
        fprintf(obj,'INST SAN');

        % Single Sweep Mode einstellen
        fprintf(obj,'INIT:CONT OFF');

        % Zero Span
        fprintf(obj,'FREQ:SPAN 0');

        % Auflsebandbreite einstellen
        if rbw == 0
            fprintf(obj,'BAND MIN');
        else
           fprintf(obj,'BAND %f',rbw);
        end
        
        % tatschliche Auflsebandbreite auslesen
        fprintf(obj,'BAND?');
        rbw = fscanf(obj,'%f');
        
        % Sweep Time einstellen
        if t == 0
            fprintf(obj,'SWE:TIME MIN');
        else
            fprintf(obj,'SWE:TIME %f',t);
        end

        % tatschliche Sweep Time auslesen
        fprintf(obj,'SWE:TIME?');
        t = fscanf(obj,'%f');
             
        % RMS Detektor, Reprsentant aus Zeitbin auswaehlen
        fprintf(obj,'DET RMS');
        
        % Gewinn einstellen
        if gain > 1
            fprintf(obj,'INP:GAIN:STAT ON'); % Vorverstrker einschalten
            gain = gain/100; % 20dB Gewinn des Vorverstrkers abziehen
            fprintf(obj,'INP:ATT %f',round(-10*log10(gain))); % Dmpfungsglied einstellen
            fprintf(obj,'INP:ATT?'); % tatschlich eingestellte Dmpfung auslesen
            gain = 100/10^(fscanf(obj,'%f')/10); % tatschlichen Gewinn berechnen
        else
            fprintf(obj,'INP:ATT %f',round(-10*log10(gain))); % Dmpfungsglied einstellen
            fprintf(obj,'INP:ATT?'); % tatschlich eingestellte Dmpfung auslesen
            gain = 1/10^(fscanf(obj,'%f')/10); % tatschlichen Gewinn berechnen
        end
        
    case 'fsq'
        % Preset
        fprintf(obj,'*RST');
        
        % Single Sweep Mode einstellen
        fprintf(obj,'INIT:CONT OFF');

        % Zero Span
        fprintf(obj,'FREQ:SPAN 0');

        % Auflsebandbreite einstellen
        if rbw == 0
            fprintf(obj,'BAND MIN');
        else
           fprintf(obj,'BAND %f',rbw);
        end
        
        % tatschliche Auflsebandbreite auslesen
        fprintf(obj,'BAND?');
        rbw = fscanf(obj,'%f');
        
        % Sweep Time einstellen
        if t == 0
            fprintf(obj,'SWE:TIME MIN');
        else
            fprintf(obj,'SWE:TIME %f',t);
        end

        % tatschliche Sweep Time auslesen
        fprintf(obj,'SWE:TIME?');
        t = fscanf(obj,'%f');

        % RMS Detektor, Reprsentant aus Zeitbin auswaehlen
        fprintf(obj,'DET RMS');  

        % Gewinn einstellen
        fprintf(obj,'INP:ATT %f',round(-10*log10(gain))); % Dmpfungsglied einstellen
        fprintf(obj,'INP:ATT?'); % tatschlich eingestellte Dmpfung auslesen
        gain = 1/10^(fscanf(obj,'%f')/10); % tatschlichen Gewinn berechnen
        
        % Reference Level einstellen
        fprintf(obj,'DISP:TRAC:Y:RLEV 0');
        
    case 'fpl'
        % Preset
        fprintf(obj,'*RST');
        
        % Single Sweep Mode einstellen
        fprintf(obj,'INIT:CONT OFF');

        % Zero Span
        fprintf(obj,'FREQ:SPAN 0');

        % Auflsebandbreite einstellen
        if rbw == 0
            fprintf(obj,'BAND MIN');
        else
           fprintf(obj,'BAND %f',rbw);
        end
        
        % tatschliche Auflsebandbreite auslesen
        fprintf(obj,'BAND?');
        rbw = fscanf(obj,'%f');
        
        % Sweep Time einstellen
        if t == 0
            fprintf(obj,'SWE:TIME MIN');
        else
            fprintf(obj,'SWE:TIME %f',t);
        end

        % tatschliche Sweep Time auslesen
        fprintf(obj,'SWE:TIME?');
        t = fscanf(obj,'%f');

        % RMS Detektor, Reprsentant aus Zeitbin auswaehlen
        fprintf(obj,'DET RMS');  

        % Gewinn einstellen
        if gain > 1
            fprintf(obj,'INP:GAIN:STAT ON'); % Vorverstrker einschalten
            gain = gain/100; % 20dB Gewinn des Vorverstrkers abziehen
            fprintf(obj,'INP:ATT %f',round(-10*log10(gain))); % Dmpfungsglied einstellen
            fprintf(obj,'INP:ATT?'); % tatschlich eingestellte Dmpfung auslesen
            gain = 100/10^(fscanf(obj,'%f')/10); % tatschlichen Gewinn berechnen
        else
            fprintf(obj,'INP:ATT %f',round(-10*log10(gain))); % Dmpfungsglied einstellen
            fprintf(obj,'INP:ATT?'); % tatschlich eingestellte Dmpfung auslesen
            gain = 1/10^(fscanf(obj,'%f')/10); % tatschlichen Gewinn berechnen
        end
        
    case 'fpc'
        % Preset
        fprintf(obj,'*RST');
        
        % Spektralanalysator aktivieren
        fprintf(obj,'INST SPEC');

        % Single Sweep Mode einstellen
        fprintf(obj,'INIT:CONT OFF');

        % Zero Span
        fprintf(obj,'FREQ:SPAN 0');

        % Auflsebandbreite einstellen
        if rbw == 0
            fprintf(obj,'BAND MIN');
        else
           fprintf(obj,'BAND %f',rbw);
        end
        
        % tatschliche Auflsebandbreite auslesen
        fprintf(obj,'BAND?');
        rbw = fscanf(obj,'%f');
        
        % Sweep Time einstellen
        if t == 0
            fprintf(obj,'SWE:TIME MIN');
        else
            fprintf(obj,'SWE:TIME %f',t);
        end

        % tatschliche Sweep Time auslesen
        fprintf(obj,'SWE:TIME?');
        t = fscanf(obj,'%f');
        
        % RMS Detektor, Reprsentant aus Zeitbin auswaehlen
        fprintf(obj,'DET RMS');
        
        % Gewinn einstellen
        if gain > 1
            fprintf(obj,'INP:GAIN:STAT ON'); % Vorverstrker einschalten
            gain = gain/100; % 20dB Gewinn des Vorverstrkers abziehen
            fprintf(obj,'INP:ATT %f',round(-10*log10(gain))); % Dmpfungsglied einstellen
            fprintf(obj,'INP:ATT?'); % tatschlich eingestellte Dmpfung auslesen
            gain = 100/10^(fscanf(obj,'%f')/10); % tatschlichen Gewinn berechnen
        else
            fprintf(obj,'INP:ATT %f',round(-10*log10(gain))); % Dmpfungsglied einstellen
            fprintf(obj,'INP:ATT?'); % tatschlich eingestellte Dmpfung auslesen
            gain = 1/10^(fscanf(obj,'%f')/10); % tatschlichen Gewinn berechnen
        end

    otherwise
    	error('unsupported spectrum analyzer');
        
end

end
